@@ -1,6 +1,6 @@
 # 
 #  This file is part of ChronoJump
-#   Copyright (C) 2015  	Xavier de Blas <xaviblas@gmail.com> 
+#   Copyright (C) 2016  	Xavier de Blas <xaviblas@gmail.com> 
 # 
 
 #Is A LOT faster to call this file from C#, and this file will do a source(scriptCaptureR)
@@ -14,9 +14,7 @@ optionsFile <- args[1]
 
 options <- scan(optionsFile, comment.char="#", what=character(), sep="\n")
 
-
-scriptUtilR = options[28]
-source(scriptUtilR)
+source(paste(options[4], "/util.R", sep=""))
 
 scriptCaptureR = options[1]
 
@@ -26,6 +24,10 @@ filenameBegins = options[2]
 
 source(scriptCaptureR)
 
+DEBUG <- FALSE
+DebugFileName <- paste(options[5], "/chronojump-debug.txt", sep="")
+
+
 f <- file("stdin")
 open(f)
 
