@@ -15,8 +15,8 @@
 #   along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
-#   Copyright (C) 2014-2015  	Xavier de Blas <xaviblas@gmail.com> 
-#   Copyright (C) 2014-2015   	Xavier Padullés <x.padulles@gmail.com>
+#   Copyright (C) 2014-2016  	Xavier de Blas <xaviblas@gmail.com> 
+#   Copyright (C) 2014-2016   	Xavier Padullés <x.padulles@gmail.com>
 # 
 
 
@@ -27,15 +27,17 @@
 #it can be printed safely to stderr. See end capture.R
 
 #used in graph.R and capture.R
-assignOptions <- function(options) {    
+assignOptions <- function(options) {
 	return(list(
 		    File		= options[1],        
 		    OutputGraph		= options[2],
 		    OutputData1		= options[3],
-		    OutputData2		= options[4], #currently used to display processing feedback
-		    SpecialData		= options[5], #currently used to write 1RM. variable;result (eg. "1RM;82.78")
+		    EncoderRScriptsPath = options[4],
+		    EncoderTempPath 	= options[5],
+		    FeedbackFileBase 	= paste(options[5], "/chronojump-encoder-status-", sep=""),
+		    SpecialData 	= paste(options[5], "/chronojump-special-data.txt", sep=""),
 		    MinHeight		= as.numeric(options[6])*10, #from cm to mm
-		    ExercisePercentBodyWeight = as.numeric(options[7]),        #was isJump=as.logical(options[6])
+		    ExercisePercentBodyWeight = as.numeric(options[7]),
 		    MassBody		= as.numeric(options[8]),
 		    MassExtra		= as.numeric(options[9]),
 		    Eccon		= options[10],
@@ -57,11 +59,11 @@ assignOptions <- function(options) {
 		    EncoderConfigurationName =	options[14],	#just the name of the EncoderConfiguration	
 		    diameter		= as.numeric(unlist(strsplit(options[15], "\\;"))), #comes in cm, will be converted to m. Since 1.5.1 can be different diameters separated by ;
 		    #diameter    = getInertialDiametersPerTick(as.numeric(unlist(strsplit("1.5; 1.75; 2.65; 3.32; 3.95; 4.07; 4.28; 4.46; 4.54; 4.77; 4.96; 5.13; 5.3; 5.55", "\\;")))),
-        diameterExt		= as.numeric(options[16]),	#comes in cm, will be converted to m
+		    diameterExt		= as.numeric(options[16]),	#comes in cm, will be converted to m
 		    anglePush 		= as.numeric(options[17]),
 		    angleWeight 	= as.numeric(options[18]),
 		    inertiaMomentum	= (as.numeric(options[19])/10000.0),	#comes in Kg*cm^2 eg: 100; convert it to Kg*m^2 eg: 0.010
-		    gearedDown 		= as.numeric(options[20]),
+		    gearedDown 		= readFromFile.gearedDown(as.numeric(options[20])),
 
 		    SmoothingOneC	= as.numeric(options[21]),
 		    Jump		= options[22],
@@ -70,13 +72,25 @@ assignOptions <- function(options) {
 		    DecimalSeparator	= options[25],
 		    Title		= options[26],
 		    OperatingSystem	= options[27],	#if this changes, change it also at start of this R file
-		    #IMPORTANT, if this grows, change the readLines value on getOptionsFromFile
-
-		    scriptOne 		= options[28], #util.R
-		    scriptTwo 		= options[29] #neuromuscularProfile.R
+		    Debug		= options[30]
+		    #Unassigned here:
+		    #	englishWords [28]
+		    #	translatedWords [29]
 		    ))
 }
 
+#gearedDown comes as:
+#4 and should be converted to 4
+#-4 and should be converted to 1/4 : 0.25
+#more info at GearedUpDisplay() on EncoderConfiguration C# class
+
+readFromFile.gearedDown <- function(gd) {
+	if(gd > 0)
+		return(gd)
+
+	return( abs( 1 / gd ) )
+}
+
 
 
 extrema <- function(y, ndata = length(y), ndatam1 = ndata - 1) {
@@ -218,15 +232,10 @@ findTakeOff <- function(forceConcentric, maxSpeedTInConcentric)
 	#2 create df2 with only the rows where force is below or equal zero
 	df2 = subset(df,subset=df$belowZero)
 
-	#print("df2")
-	#print(df2)
-
 	#3 find takeoff as the df2 row with less distance to maxSpeedT
 	df2row = min(which(df2$dist == min(df2$dist)))
 	takeoff = as.integer(rownames(df2)[df2row])
 
-	#print(c("takeoff",takeoff))
-
 	return(takeoff)
 }
 	
@@ -238,11 +247,43 @@ getSpeedSafe <- function(displacement, smoothing) {
 	else
 		return(list(y=rep(0,length(displacement))))
 }
+#unused since 1.6.0 because first and last displacement values make change too much the initial and end curve
+#getSpeedOld <- function(displacement, smoothing) {
+#	#no change affected by encoderConfiguration
+#	return (smooth.spline( 1:length(displacement), displacement, spar=smoothing))
+#}
 getSpeed <- function(displacement, smoothing) {
 	#no change affected by encoderConfiguration
-	return (smooth.spline( 1:length(displacement), displacement, spar=smoothing))
+	
+	#use position because this does not make erronously change the initial and end of the curve
+	#do spline with displacement is buggy because data is too similar -2, -1, 0, 1, 2, ...
+	position <- cumsum(displacement)
+	positionSpline <- smooth.spline( 1:length(position), position, spar=smoothing)
+	
+	#get speed converting from position to displacement, but repeat first value because it's missing on the diff process
+	#do not hijack spline like this because this works for speed, but then acceleration has big error
+	#speedSpline = positionSpline
+	#speedSpline$y = c(diff(positionSpline$y)[1],diff(positionSpline$y))
+
+	speed = c(diff(positionSpline$y)[1],diff(positionSpline$y))
+	speedSpline <- smooth.spline( 1:length(speed), speed, spar=0) #don't do smoothing, just convert speed to an spline
+
+	return (speedSpline)
 }
 
+#same smoothing than getSped
+getPositionSmoothed <- function(displacement, smoothing) {
+	#no change affected by encoderConfiguration
+	
+	#use position because this does not make erronously change the initial and end of the curve
+	#do spline with displacement is buggy because data is too similar -2, -1, 0, 1, 2, ...
+	position <- cumsum(displacement)
+	positionSpline <- smooth.spline( 1:length(position), position, spar=smoothing)
+	
+	return (positionSpline$y)
+}
+
+
 getAccelerationSafe <- function(speed) {
 	#x vector should contain at least 4 different values
 	if(length(speed) >= 4)
@@ -361,48 +402,89 @@ reduceCurveBySpeed <- function(eccon, row, startT, startH, displacement, smoothi
 				x.end = i
 	}
 
-	#print(speed.ext$cross[,2])
-	#print(ext.cross.len)
-	#print(c("time1,time2",time1,time2))
-	#print(c("x.ini x.end",x.ini,x.end))
-
 	#to know the new startH
 	#calculate displacement from original start to the new: x.ini
 	startH.old = startH
 	startH = startH + sum(displacement[1:x.ini])
-	#print(c("old startH:", startH.old, "; new startH:", startH))
 
 	return(c(startT + x.ini, startT + x.end, startH))
 }
 
+
+#for graph.R, if single file all repetitions have Roptions, but if not, each one has different values
+#for capture.R pass singleFile as TRUE, curves as NULL, and i as NULL
+assignRepOptions <- function(
+			      singleFile, curves, i,
+			      massBody, massExtra, eccon, exPercentBodyWeight, 
+			      econfName, diameter, diameterExt, 
+			      anglePush, angleWeight, inertiaM, gearedDown,
+			      laterality) 
+{
+	if(singleFile) {
+		return(list(
+			      massBody = massBody, 
+			      massExtra = massExtra, 
+			      eccon = eccon, 
+			      exPercentBodyWeight = exPercentBodyWeight, 
+			      
+			      econfName = econfName, 
+			      diameter = diameter, 
+			      diameterExt = diameterExt, 
+			      anglePush = anglePush, 
+			      angleWeight = angleWeight, 
+			      inertiaM = inertiaM, 
+			      gearedDown = gearedDown,
+			      laterality = laterality
+			    ))
+	} else {
+		return(list(
+			      massBody = curves[i,5], 
+			      massExtra = curves[i,6], 
+			      eccon = curves[i,8], 
+			      exPercentBodyWeight = curves[i,10], 
+			      
+			      econfName = curves[i,11], 
+			      diameter = curves[i,12], 
+			      diameterExt = curves[i,13], 
+			      anglePush = curves[i,14], 
+			      angleWeight = curves[i,15], 
+			      inertiaM = curves[i,16], 
+			      gearedDown = curves[i,17],
+			      laterality = curves[i,18] 
+			    ))
+	}
+}
+
+
+
 #go here with every single curve
-#eccon="c" one time each curve
-#eccon="ec" one time each curve
-#eccon="ecS" means ecSeparated. two times each curve: one for "e", one for "c"
-kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWeight,
-			encoderConfigurationName,diameter,diameterExt,anglePush,angleWeight,inertiaMomentum,gearedDown,
-			smoothingOneEC, smoothingOneC, g, eccon, isPropulsive)
+#repOp has the options for this repetition
+#repOp$eccon="c" one time each curve
+#repOp$eccon="ec" one time each curve
+#repOp$eccon="ecS" means ecSeparated. two times each curve: one for "e", one for "c"
+#kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWeight,
+#			encoderConfigurationName,diameter,diameterExt,anglePush,angleWeight,inertiaMomentum,gearedDown,
+#			smoothingOneEC, smoothingOneC, g, eccon, isPropulsive)
+#eccModesStartOnGround is default mode for calculations on e, ec starting when person lands,
+#	but on single analysis instant array, disable it in order to see the full repetition
+#	also think what to do on export CSV
+kinematicsF <- function(displacement, repOp, smoothingOneEC, smoothingOneC, g, isPropulsive, eccModesStartOnGround)
 {
 	print("at kinematicsF")
 
 	smoothing = 0
-	if(eccon == "c" || eccon == "e")
+	if(repOp$eccon == "c" || repOp$eccon == "e")
 		smoothing = smoothingOneC
 	else
 		smoothing = smoothingOneEC
 	
 
-	print(c("eccon, smoothing:",eccon, smoothing))
+	print(c("repOp$eccon, smoothing:", repOp$eccon, smoothing))
 
 	speed <- getSpeedSafe(displacement, smoothing)
 	
 	accel <- getAccelerationSafe(speed)
 	
-	#print(c(" ms",round(mean(speed$y),5)," ma",round(mean(accel$y),5)))
-	#print(c(" Ms",round(max(speed$y),5)," Ma",round(max(accel$y),5)))
-	#print(c(" |ms|",round(mean(abs(speed$y)),5)," |ma|:",round(mean(abs(accel$y)),5)))
-	#print(c(" |Ms|",round(max(abs(speed$y)),5)," |Ma|",round(max(abs(accel$y)),5)))
-
 	#speed comes in mm/ms when derivate to accel its mm/ms^2 to convert it to m/s^2 need to *1000 because it's quadratic
 	accel$y <- accel$y * 1000 
 
@@ -410,20 +492,18 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 	concentric = 0
 	propulsiveEnd = 0
 
-	#print(c("at kinematicsF eccon: ", eccon, " length(displacement): ",length(displacement)))
-
 	#search propulsiveEnd
 	if(isPropulsive) {
-		if(eccon=="c") {
+		if(repOp$eccon=="c") {
 			concentric=1:length(displacement)
 			
 			maxSpeedT <- min(which(speed$y == max(speed$y)))
 			maxSpeedTInConcentric = maxSpeedT
 			
-			propulsiveEnd = findPropulsiveEnd(accel$y,concentric,maxSpeedTInConcentric,
-							  encoderConfigurationName, anglePush, angleWeight, 
-							  massBody, massExtra, exercisePercentBodyWeight)
-		} else if(eccon=="ec") {
+			propulsiveEnd = findPropulsiveEnd(accel$y, concentric, maxSpeedTInConcentric,
+							  repOp$econfName, repOp$anglePush, repOp$angleWeight, 
+							  repOp$massBody, repOp$massExtra, repOp$exPercentBodyWeight)
+		} else if(repOp$eccon=="ec") {
 			phases=findECPhases(displacement,speed$y)
 			eccentric = phases$eccentric
 			isometric = phases$isometric
@@ -437,21 +517,21 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 				maxSpeedTInConcentric = maxSpeedT - (length(eccentric) + length(isometric))
 
 				propulsiveEnd = length(eccentric) + length(isometric) + 
-						findPropulsiveEnd(accel$y,concentric,maxSpeedTInConcentric, 
-								  encoderConfigurationName, anglePush, angleWeight, 
-								  massBody, massExtra, exercisePercentBodyWeight)
-				#print(c("lengths: ", length(eccentric), length(isometric), findPropulsiveEnd(accel$y,concentric), propulsiveEnd))
+						findPropulsiveEnd(accel$y, concentric, maxSpeedTInConcentric, 
+								  repOp$econfName, repOp$anglePush, repOp$angleWeight, 
+								  repOp$massBody, repOp$massExtra, repOp$exPercentBodyWeight)
 			}
-		} else if(eccon=="e") {
-			#not eccon="e" because not propulsive calculations on eccentric
+		} else if(repOp$eccon=="e") {
+			#not repOp$eccon="e" because not propulsive calculations on eccentric
 		} else { #ecS
 			#print("WARNING ECS\n\n\n\n\n")
 		}
 	}
 
-	dynamics = getDynamics(encoderConfigurationName,
-			speed$y, accel$y, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight,
-			displacement, diameter, inertiaMomentum, smoothing)
+	dynamics = getDynamics(repOp$econfName,
+			speed$y, accel$y, repOp$massBody, repOp$massExtra, repOp$exPercentBodyWeight, 
+			repOp$gearedDown, repOp$anglePush, repOp$angleWeight,
+			displacement, repOp$diameter, repOp$inertiaM, smoothing)
 	mass = dynamics$mass
 	force = dynamics$force
 	power = dynamics$power
@@ -461,12 +541,13 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 
 
 	#on "e", "ec", start on ground
-	if(! isInertial(encoderConfigurationName) && (eccon == "e" || eccon == "ec")) {
+	if(eccModesStartOnGround && ! isInertial(repOp$econfName) && 
+	   (repOp$eccon == "e" || repOp$eccon == "ec")) {
 		#if eccentric is undefined, find it
 		if(eccentric == 0) {
-			if(eccon == "e")
+			if(repOp$eccon == "e")
 				eccentric = 1:length(displacement)
-			else {  #(eccon=="ec")
+			else {  #(repOp$eccon=="ec")
 				phases=findECPhases(displacement,speed$y)
 				eccentric = phases$eccentric
 			}
@@ -479,30 +560,19 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 		}
 	}
 
-	if( isPropulsive && ( eccon== "c" || eccon == "ec" ) )
+	if( isPropulsive && ( repOp$eccon== "c" || repOp$eccon == "ec" ) )
 		end <- propulsiveEnd
 
 	#as acceleration can oscillate, start at the eccentric part where there are not negative values
-	#print(c(inertiaMomentum, eccon, length(eccentric), min(accel$y[eccentric])))
-	if(inertiaMomentum > 0 && (eccon == "e" || eccon == "ec")) 
+	if(repOp$inertiaM > 0 && (repOp$eccon == "e" || repOp$eccon == "ec")) 
 	{
-		if(eccon=="e") {
+		if(repOp$eccon=="e") {
 			eccentric=1:length(displacement)
 		}
 		
 		#if there is eccentric data and there are negative values
 	   	if(length(eccentric) > 0 && min(accel$y[eccentric]) < 0)
 		{ 
-			#print(c("length(eccentric)",length(eccentric)))
-			#print("min accel y eccentric ++++++++++++")
-			#print(c("min(accel$y[eccentric])",min(accel$y[eccentric])))
-	
-			#print(c("accel$y[eccentric]", accel$y[eccentric]))
-			#print("displacement eccentric")
-			#print(displacement[eccentric])
-
-
-
 			#deactivated:
 			#start = max(which(accel$y[eccentric] < 0)) +1
 			#print("------------ start -----------")
@@ -511,12 +581,12 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 	}
 
 	#print(c("kinematicsF start end",start,end))
-			
 	#write("kinematicsF speed length and mean,", stderr())
 	#write(length(speed$y[start:end]), stderr())
 	#write(mean(speed$y[start:end]), stderr())
 
 	return(list(
+		    displ = displacement[start:end], 
 		    speedy = speed$y[start:end], 
 		    accely = accel$y[start:end], 
 		    force = force[start:end], 
@@ -526,28 +596,17 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 
 findECPhases <- function(displacement,speed) {
 	speed.ext=extrema(speed)
-	#print(speed.ext)
-	#print(speed)
 	
 	#In all the extrema minindex values, search which range (row) has the min values,
 	#and in this range search last value
-	#print("searchMinSpeedEnd")
 	searchMinSpeedEnd = max(which(speed == min(speed)))
-	#print(searchMinSpeedEnd)
 	
 	#In all the extrema maxindex values, search which range (row) has the max values,
 	#and in this range search first value
-	#print("searchMaxSpeedIni")
 	searchMaxSpeedIni = min(which(speed == max(speed)))
-	#print(searchMaxSpeedIni)
 	
 	#find the cross between both
-	#print("speed.ext-Cross")
-	#print(speed.ext$cross[,1])
-	#print("search min cross: crossMinRow")
-
 	crossMinRow=which(speed.ext$cross[,1] > searchMinSpeedEnd & speed.ext$cross[,1] < searchMaxSpeedIni)
-	#print(crossMinRow)
 			
 	
 	eccentric = 0
@@ -564,8 +623,6 @@ findECPhases <- function(displacement,speed) {
 
 	isometricUse = TRUE
 
-	#print("at findECPhases")
-
 	if(isometricUse) {
 		eccentric=1:min(speed.ext$cross[crossMinRow,1])
 		isometric=min(speed.ext$cross[crossMinRow,1]+1):max(speed.ext$cross[crossMinRow,2])
@@ -621,10 +678,8 @@ findPropulsiveEnd <- function(accel, concentric, maxSpeedTInConcentric,
 return (propulsiveEnd)
 }
 
-pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, inertiaMomentum) {
-	#print("speed$y")
-	#print(kinematics$speedy)
-
+pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, inertiaMomentum) 
+{
 	meanSpeed <- mean(kinematics$speedy)
 
 	#max speed and max speed time can be at eccentric or concentric
@@ -638,15 +693,9 @@ pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, iner
 		meanPower <- mean(abs(kinematics$power))
 	}
 
-	#print(c("eccon meanPowerSigned meanPowerABS",eccon, mean(kinematics$power), mean(abs(kinematics$power))))
-	#print("kinematics$power")
-	#print(abs(kinematics$power))
-
 	peakPower <- max(abs(kinematics$power))
 	peakPowerT <- min(which(abs(kinematics$power) == peakPower))
 	
-	#print(which(abs(kinematics$power) == peakPower))
-
 	pp_ppt <- peakPower / (peakPowerT/1000)	# ms->s
 	meanForce <- mean(kinematics$force)
 	maxForce <- max(abs(kinematics$force))
@@ -690,42 +739,47 @@ getDynamics <- function(encoderConfigurationName,
 			speed, accel, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight,
 			displacement, diameter, inertiaMomentum, smoothing)
 {
-  massBody = getMassBodyByExercise(massBody,exercisePercentBodyWeight)
-  
-  if(
-    encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1" ||
-      encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1INV" ||
-      encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2" ||
-      encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2INV" ||
-      encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYFRICTION" ||
-      encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYAXIS" ) 
-  {
-    massExtra = getMass(massExtra, gearedDown, anglePush)
-  } 
-  
-  massTotal = massBody + massExtra
-  
-  if(isInertial(encoderConfigurationName))
-    return (getDynamicsInertial(encoderConfigurationName, displacement, diameter, massTotal, inertiaMomentum, smoothing))
-  else 
-    return (getDynamicsNotInertial (encoderConfigurationName, speed, accel, 
-                                    massBody, massExtra, massTotal, 
-                                    exercisePercentBodyWeight, gearedDown, anglePush, angleWeight))
+	debugParameters(listN(encoderConfigurationName,
+			     speed, accel, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight,
+			     displacement, diameter, inertiaMomentum, smoothing), "getDynamics")
+	
+
+	massBody = getMassBodyByExercise(massBody,exercisePercentBodyWeight)
+
+	if(
+	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1" ||
+	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1INV" ||
+	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2" ||
+	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2INV" ||
+	   encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYFRICTION" ||
+	   encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYAXIS" ) 
+	{
+		massExtra = getMass(massExtra, gearedDown, anglePush)
+	} 
+
+	massTotal = massBody + massExtra
+
+	if(isInertial(encoderConfigurationName))
+		return (getDynamicsInertial(encoderConfigurationName, displacement, diameter, massTotal, inertiaMomentum, gearedDown, smoothing))
+	else 
+		return (getDynamicsNotInertial (encoderConfigurationName, speed, accel, 
+						massBody, massExtra, massTotal, 
+						exercisePercentBodyWeight, gearedDown, anglePush, angleWeight))
 }
 
 #mass extra can be connected to body or connected to a pulley depending on encoderConfiguration
 getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel, 
-                                   massBody, massExtra, massTotal,
-                                   exercisePercentBodyWeight, gearedDown, anglePush, angleWeight) 
+				   massBody, massExtra, massTotal,
+				   exercisePercentBodyWeight, gearedDown, anglePush, angleWeight) 
 { 
-  force = NULL
-  if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
-    force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel)
-  } else if(encoderConfigurationName == "LINEARONPLANE"){
-    force <- (massBody + massExtra)*(accel + g*sin(anglePush * pi / 180))
-  } else {
-  	force <- massTotal*(accel+g)	#g:9.81 (used when movement is against gravity)
-  }
+	force = NULL
+	if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
+		force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel)
+	} else if(encoderConfigurationName == "LINEARONPLANE"){
+		force <- (massBody + massExtra)*(accel + g*sin(anglePush * pi / 180))
+	} else {
+		force <- massTotal*(accel+g)	#g:9.81 (used when movement is against gravity)
+	}
 
 	power <- force*speed
 
@@ -743,7 +797,7 @@ getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel,
 #  ROTARYAXISINERTIAL Rotary axis encoder  connected to inertial machine on the axis
 #  ROTARYAXISINERTIALMOVPULLEY Rotari axis encoder connected to inertial machine on the axis and the subject pulling from a moving pulley
 
-getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter, mass, inertiaMomentum, smoothing)
+getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter, mass, inertiaMomentum, gearedDown, smoothing)
 {
 	speed = getSpeed(displacement, smoothing) #mm/ms == m/s 
 
@@ -817,7 +871,7 @@ getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter
 
   }
 
-  force = forceDisc + forceBody
+  force = forceDisc / gearedDown + forceBody
   power = powerDisc + powerBody
 
   loopsMax = diameter.m * max(angle)
@@ -874,45 +928,38 @@ getDisplacement <- function(encoderConfigurationName, displacement, diameter, di
 #This function converts angular information from rotary encoder to linear information like linear encoder
 #This is NOT the displacement of the person because con-ec phases roll in the same direction
 #This is solved by the function getDisplacementInertialBody
-getDisplacementInertial <- function(displacement, encoderConfigurationName, diameter, diameterExt)
+getDisplacementInertial <- function(displacement, encoderConfigurationName, diameter, diameterExt, gearedDown)
 {
 	write("at getDisplacementInertial", stderr())
-
+	
 	#scanned displacement is ticks of rotary axis encoder
 	#now convert it to mm of body displacement
 	if(encoderConfigurationName == "ROTARYAXISINERTIAL" ||
-	     encoderConfigurationName == "ROTARYAXISINERTIALLATERAL") {
-		displacementMeters = displacement / 1000 #mm -> m
-		diameterMeters = diameter / 100 #cm -> m
-		ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks per turn
-		#angle in radians
-		angle = cumsum(displacementMeters * 1000) * 2 * pi / ticksRotaryEncoder
-		position = angle * diameterMeters / 2
-		position = position * 1000	#m -> mm
-		#this is to make "inverted cumsum"
-		displacement = diff(position) #this displacement is going to be used now
-		displacement = c(displacement[1],displacement) #this is to recuperate the lost 1st value in the diff operation
+	     encoderConfigurationName == "ROTARYAXISINERTIALLATERAL" ||
+	     encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY") {
+	        ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks per revolution
+	        
+	        #Number of revolutions that the flywheel rotates every millisecond
+	        revolutionsPerMs = displacement / ticksRotaryEncoder # One revolution every ticksRotaryEncoder ticks
+	        
+	        #The person is gearedDown from the machine point of view 
+	        #If force multiplier is 2 (gearedDown = 0.5) the displacement of the body is 
+	        #half the the displacement at the perimeter of the axis
+	        displacement = revolutionsPerMs * pi * diameter * 10 * gearedDown # Revolutions * perimeter * gearedDown  and converted cm -> mm
+	        
 	} else if(encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL" ||
-              encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL"){
-	  displacement = displacement * diameter / diameterExt #displacement of the axis
+                encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL" ||
+                encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALMOVPULLEY"){
+	        
+	        displacement = displacement * diameter * gearedDown / diameterExt #displacement of the axis
+	        
 	} else if(encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALMOVPULLEY"){
-	  displacement = displacement / 2 #Half the displacement of the axis
-	} else if(encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALMOVPULLEY"){
-	  displacement = displacement * diameter /(2 * diameterExt) #Half the displacement of the axis
-	} else if(encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY"){
-	  displacementMeters = displacement / 1000 #mm -> m
-	  diameterMeters = diameter / 100 #cm -> m
-	  ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks per turn
-	  #angle in radians
-	  angle = cumsum(displacementMeters * 1000) * 2 * pi / ticksRotaryEncoder
-	  position = angle * diameterMeters / 2
-	  position = position * 500	#m -> mm and the rope moves twice as the body
-	  #this is to make "inverted cumsum"
-	  displacement = diff(position) #this displacement is going to be used now
-	  displacement = c(displacement[1],displacement) #this is to recuperate the lost 1st value in the diff operation
+	        #If force multiplier is 2 (gearedDown = 0.5) the displacement of the body is 
+	        #half the the displacement at the perimeter of the axis
+	        displacement = displacement * gearedDown
+	  
 	}
 	
-	
 	return (displacement)
 }
 
@@ -934,7 +981,6 @@ getDisplacementInertialBody <- function(positionStart, displacement, draw, title
 	position.ext=extrema(position)
 
 	#print("at findCurvesInertial")
-	#print(position.ext)
 
 	#do if extrema(position)$nextreme == 0... then do not use extrema
 	#TODO: check if started backwards on realtime capture (extrema is null)
@@ -995,8 +1041,12 @@ getDisplacementInertialBody <- function(positionStart, displacement, draw, title
 		lines((1:length(position))/1000,positionPerson/10,lty=1,lwd=2)
 
 		title(title, cex.main=1, font.main=1)
-		mtext(paste(translateToPrint("time"),"(s)"),side=1,adj=1,line=-1)
-		mtext(paste(translateToPrint("displacement"),"(cm)"),side=2,adj=1,line=-1)
+		
+		#disabled because translateToPrint is on graph.R (not called by capture.R)
+		#mtext(paste(translateToPrint("time"),"(s)"),side=1,adj=1,line=-1)
+		#mtext(paste(translateToPrint("displacement"),"(cm)"),side=2,adj=1,line=-1)
+		mtext("time (s)", side=1, adj=1, line=-1)
+		mtext("displacement (cm)", side=2, adj=1, line=-1)
 	}
 	return(displacementPerson)
 }
@@ -1065,3 +1115,71 @@ getInertialDiametersPerMs <- function(displacement, diametersPerTick)
   return(diameter)
 }
 
+
+
+#----------- Begin debug file output -------------
+debugParameters <- function (parameterList, currentFunction) 
+{
+	if(is.null(DEBUG) || DEBUG == FALSE || is.null(DebugFileName) || DebugFileName == "")
+		return()
+
+        write(paste("Parameters of the", currentFunction, "function are:\n"), DebugFileName, append=TRUE)
+        
+        #based on http://stackoverflow.com/a/34996874
+        for (i in 1:length(parameterList)) {
+                if ( (is.character(parameterList[[i]]) || is.numeric(parameterList[[i]])) &&
+                    ! is.data.frame(parameterList[[i]]) && ! is.matrix(parameterList[[i]]) ) {
+			writedebugParameters(parameterList, i)
+                        write(paste(parameterList[[i]],collapse = " "), DebugFileName, append=TRUE)
+                }
+                if (is.data.frame(parameterList[[i]])) {
+			writedebugParameters(parameterList, i)
+                        write.table(parameterList[[i]], DebugFileName, append=TRUE, quote=FALSE, sep="\t", col.names = TRUE)
+                }
+                else if (is.POSIXlt(parameterList[[i]])) {
+			writedebugParameters(parameterList, i)
+                        write(as.character(parameterList[[i]]), DebugFileName, append=TRUE)
+                }
+                else if  (is.list(parameterList[[i]])) {
+			writedebugParameters(parameterList, i)
+                        write_list(parameterList = parameterList[[i]], DebugFileName, append = TRUE)
+                }
+                else if (is.matrix(parameterList[[i]])) {
+			writedebugParameters(parameterList, i)
+                        write.table(parameterList[[i]], DebugFileName, append=TRUE, quote=FALSE, col.names = TRUE)
+                }
+        }
+}
+
+writedebugParameters <- function(parameterList, i) {
+	write(paste("---------", names(parameterList)[i], ":", "---------", sep = ""), DebugFileName, append=TRUE) 
+}
+
+is.POSIXlt <- function (ts) {
+        isPOS=c("POSIXlt", "POSIXt")
+        identical (class(ts),isPOS)
+}
+
+test_debugParameters <- function() {
+        numVariable = c(1,2,3,4)
+        charVariable = c("Hello", "how", "are", "you")
+        dataframeVariable = as.data.frame(matrix(c(10,20,40,50), ncol = 2))
+        matrixVariable = matrix(c(100,200,400,500), ncol = 2)
+
+	l = list(numVariable = numVariable,
+		 charVariable = charVariable,
+		 dataframeVariable = dataframeVariable,
+		 matrixVariable = matrixVariable)
+        
+        debugParameters(l, "test_debugParameters")
+}
+
+#create a list assigning names
+#http://stackoverflow.com/a/21059868
+listN <- function(...){
+	anonList <- list(...)
+	names(anonList) <- as.character(substitute(list(...)))[-1]
+	anonList
+}
+
+#----------- End debug file output -------------
