@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 
@@ -111,6 +111,12 @@ public class ChronoJump
 					LogB.Information("environments");
 					LogB.Information(Environment.GetEnvironmentVariable("R_HOME"));
 					LogB.Information(Environment.GetEnvironmentVariable("PATH"));
+
+					//Gstreamer stuff
+					string prefix="/Applications/Chronojump.app/Contents/Home/";
+					Environment.SetEnvironmentVariable ("GST_PLUGIN_PATH", prefix + "lib/gstreamer-0.10");
+					Environment.SetEnvironmentVariable ("GST_PLUGIN_SYSTEM_PATH", prefix + "lib/gstreamer-0.10");
+					Environment.SetEnvironmentVariable ("GST_PLUGIN_SCANNER_PATH", prefix + "lib/gstreamer-0.10/gst-plugin-scanner");
 					break;
 				case UtilAll.OperatingSystems.LINUX:
 					rBinPath = @"/usr/lib/R/lib";
