@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -413,6 +413,7 @@ public class Constants
 
 	public static string FileNameEncoderAnalyzePowerbarsIcon = "encoder-analyze-powerbars.png";
 	public static string FileNameEncoderAnalyzeCrossIcon = "encoder-analyze-cross.png";
+	public static string FileNameEncoderAnalyze1RMIcon = "encoder-analyze-1RM.png";
 	public static string FileNameEncoderAnalyzeSideIcon = "encoder-analyze-side.png";
 	public static string FileNameEncoderAnalyzeSingleIcon = "encoder-analyze-single.png";
 	public static string FileNameEncoderAnalyzeNmpIcon = "encoder-analyze-nmp.png";
@@ -429,6 +430,7 @@ public class Constants
 	public static string FileNameEncoderAnalyzeMaxIcon = "encoder-analyze-max.png";
 	public static string FileNameEncoderAnalyzeRangeIcon = "encoder-analyze-range.png";
 	public static string FileNameEncoderAnalyzeTimeToPPIcon = "encoder-analyze-time-to-pp.png";
+	public static string FileNameEncoderInertialInstructions = "inertial-start.png";
 	
 	public static string FileNameAutoPersonSkipIcon = "auto-person-skip.png";
 	public static string FileNameAutoPersonRemoveIcon = "auto-person-remove.png";
@@ -689,6 +691,15 @@ public class Constants
 	 * chronojump / encoder / sessionID / graphs
 	 */
 	
+	/*
+	 * The installer as from R 3.2.2 puts links to R and Rscript
+	 * in /usr/bin (Mavericks, Yosemite) or /usr/local/bin (El Capitan and later).
+	 * If these are missing, you can run directly the versions in /Library/Frameworks/R.framework/Resources/.
+	 * https://cran.r-project.org/doc/manuals/r-devel/R-admin.pdf
+	 */
+	public static string ROSX = "/Library/Frameworks/R.framework/Resources/R";
+	public static string RScriptOSX = "/Library/Frameworks/R.framework/Resources/RScript";
+	
 	//public static string EncoderScriptCapturePythonLinux = "pyserial_pyper.py";
 	//public static string EncoderScriptCapturePythonWindows = "pyserial_pyper_windows.exe";
 	public static string EncoderScriptCallCaptureNoRDotNet = "call_capture.R";
@@ -713,6 +724,7 @@ public class Constants
 	
 	public static string EncoderExportTemp = "chronojump-export.csv";
 	public static string EncoderSpecialDataTemp = "chronojump-special-data.txt"; //variable;result (eg. "1RM;82.78")
+	public static string EncoderInstantDataTemp = "chronojump-analysis-instant.csv";
 
 	//note next has 40 chars, and its used also in encoder/graph.R to detect how a file will be treated
 	//if this name changes, change it in encoder/graph.R
@@ -722,7 +734,7 @@ public class Constants
 	public static string EccentricConcentric = "Eccentric-concentric";
 	//public static string ConcentricEccentric = "Concentric-eccentric";
 
-	public enum EncoderCheckFileOp { CAPTURE_EXPORT_ALL, ANALYZE_SAVE_IMAGE, ANALYZE_SAVE_TABLE}
+	public enum EncoderCheckFileOp { CAPTURE_EXPORT_ALL, ANALYZE_SAVE_IMAGE, ANALYZE_SAVE_AB, ANALYZE_SAVE_TABLE}
 
 	public static double EncoderErrorCode = -1;
 	
@@ -790,17 +802,17 @@ public class Constants
 		LINEAR, ROTARYFRICTION, ROTARYAXIS
 	}	
 
-	public static string MeanSpeed = "Mean speed";
-	public static string MaxSpeed = "Max speed";
-	public static string MeanForce = "Mean force";
-	public static string MaxForce = "Max force";
-	public static string MeanPower = "Mean power";
-	public static string PeakPower = "Peak power";
+	public const string MeanSpeed = "Mean speed";
+	public const string MaxSpeed = "Max speed";
+	public const string MeanForce = "Mean force";
+	public const string MaxForce = "Max force";
+	public const string MeanPower = "Mean power";
+	public const string PeakPower = "Peak power";
 		
 	public enum Encoder1RMMethod { NONWEIGHTED, WEIGHTED, WEIGHTED2, WEIGHTED3 }
 	public enum ContextMenu { NONE, EDITDELETE, DELETE }
 	
-	public enum EncoderAutoSaveCurve { ALL, NONE, BESTMEANPOWER }
+	public enum EncoderAutoSaveCurve { ALL, NONE, BEST }
 
 	public enum DoubleContact {
 		NONE, FIRST, AVERAGE, LAST
