@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -131,18 +131,21 @@ public class EncoderStruct
 	public string InputData;
 	public string OutputGraph;
 	public string OutputData1;
-	public string OutputData2;
-	public string SpecialData;
+	public string EncoderRPath; //to load other R scripts
+	public string EncoderTempPath; //use for Status, Special, GraphParams....
 	public EncoderParams Ep;
 
-	public EncoderStruct(string InputData, string OutputGraph, string OutputData1, string OutputData2,
-			string SpecialData, EncoderParams Ep)
+	//pass this to R
+	public EncoderStruct(string InputData, string OutputGraph, 
+			string OutputData1, 
+			string EncoderRPath, string EncoderTempPath,
+			EncoderParams Ep)
 	{
 		this.InputData = InputData;
 		this.OutputGraph = OutputGraph;
 		this.OutputData1 = OutputData1;
-		this.OutputData2 = OutputData2;
-		this.SpecialData = SpecialData;
+		this.EncoderRPath = EncoderRPath;
+		this.EncoderTempPath = EncoderTempPath;
 		this.Ep = Ep;
 	}
 
@@ -154,39 +157,34 @@ public class EncoderGraphROptions
 	public string inputData;
 	public string outputGraph;
 	public string outputData1;
-	public string outputData2;
-	public string specialData;
+	public string encoderRPath;
+	public string encoderTempPath;
 	public EncoderParams ep;
 	public string title;
 	public string operatingSystem;
-	public string scriptUtilR;
-	public string scriptNeuromuscularProfile;
 	public string englishWords;
 	public string translatedWords;
-	public string scriptGraphR;
+	public bool debug;
 	
 	public EncoderGraphROptions(
 			string inputData, string outputGraph, string outputData1, 
-			string outputData2, string specialData, 
+			string encoderRPath, string encoderTempPath,
 			EncoderParams ep,
 			string title, string operatingSystem,
-			string scriptUtilR, string scriptNeuromuscularProfile,
 			string englishWords, string translatedWords,
-			string scriptGraphR) 
+			bool debug)
 	{
 		this.inputData = inputData;
 		this.outputGraph = outputGraph;
 		this.outputData1 = outputData1;
-		this.outputData2 = outputData2;
-		this.specialData = specialData;
+		this.encoderRPath = encoderRPath;
+		this.encoderTempPath = encoderTempPath;
 		this.ep = ep;
 		this.title = title;
 		this.operatingSystem = operatingSystem;
-		this.scriptUtilR = scriptUtilR;
-		this.scriptNeuromuscularProfile = scriptNeuromuscularProfile;
 		this.englishWords = englishWords;
 		this.translatedWords = translatedWords;
-		this.scriptGraphR = scriptGraphR;
+		this.debug = debug;
 	}
 
 	public override string ToString() {
@@ -194,17 +192,16 @@ public class EncoderGraphROptions
 			"#inputdata\n" + 	inputData + "\n" + 
 			"#outputgraph\n" + 	outputGraph + "\n" + 
 			"#outputdata1\n" + 	outputData1 + "\n" + 
-			"#outputdata2\n" + 	outputData2 + "\n" + 
-			"#specialdata\n" + 	specialData + "\n" + 
+			"#encoderRPath\n" + 	encoderRPath + "\n" + 
+			"#encoderTempPath\n" + 	encoderTempPath + "\n" + 
 			ep.ToStringROptions() + "\n" + 
 			"#title\n" + 		title + "\n" + 
 			"#operatingsystem\n" + 	operatingSystem + "\n" +
-			"#scriptUtilR\n" + 	scriptUtilR + "\n" + 
-			"#scriptNeuromuscularProfile\n" + scriptNeuromuscularProfile + "\n" +
 			"#englishWords\n" + 	englishWords + "\n" +
-			"#translatedWords\n" + 	translatedWords + "\n" + 
-			"#scriptGraphR\n" + 	scriptGraphR + "\n";
+			"#translatedWords\n" + 	translatedWords + "\n" +
+			"#debug\n" +		Util.BoolToRBool(debug) + "\n";
 	}
+	
 
 	~EncoderGraphROptions() {}
 }
@@ -221,6 +218,7 @@ public class EncoderCurve
 	public string Laterality;	//only on analyze
 	public double ExtraWeight;
 	public double DisplacedWeight;
+	public int Inertia;
 	public string Start;
 	public string Duration;
 	public string Height;
@@ -268,6 +266,7 @@ public class EncoderCurve
 	public EncoderCurve (string n, string series, string exercise, 
 			string laterality,
 			double extraWeight, double displacedWeight,
+			int inertia,
 			string start, string duration, string height,
 			string meanSpeed, string maxSpeed, string maxSpeedT,
 			string meanPower, string peakPower, string peakPowerT, 
@@ -280,6 +279,7 @@ public class EncoderCurve
 		this.Laterality = laterality;
 		this.ExtraWeight = extraWeight;
 		this.DisplacedWeight = displacedWeight;
+		this.Inertia = inertia;
 		this.Start = start;
 		this.Duration = duration;
 		this.Height = height;
@@ -326,25 +326,55 @@ public class EncoderCurve
 	}
 	//at least for RenderNAnalyze
 	public bool IsValidN() {
-		if (N == "AVG" || N == "SD" || IsNumberN() || IsNumberNandEorC())
+		if (N == "MAX" || N == "AVG" || N == "SD" || IsNumberN() || IsNumberNandEorC())
 			return true;
 		return false;
 	}
 
+	public double GetParameter(string parameter) {
+		switch(parameter) {
+			case Constants.MeanSpeed:
+				return Convert.ToDouble(MeanSpeed);
+				break;
+			case Constants.MaxSpeed:
+				return Convert.ToDouble(MaxSpeed);
+				break;
+			case Constants.MeanForce:
+				return Convert.ToDouble(MeanForce);
+				break;
+			case Constants.MaxForce:
+				return Convert.ToDouble(MaxForce);
+				break;
+			case Constants.MeanPower:
+				return Convert.ToDouble(MeanPower);
+				break;
+			case Constants.PeakPower:
+				return Convert.ToDouble(PeakPower);
+				break;
+			default:
+				return Convert.ToDouble(MeanPower);
+				break;
+		}
+	}
+
+	public string ToCSV(bool captureOrAnalyze, string decimalSeparator) {
 
-	public string ToCSV(string decimalSeparator) {
 		//latin:	2,3 ; 2,5
 		//non-latin:	2.3 , 2.5
 
 		string sep = ":::";
-		string str = 
-			N + sep + Series + sep + Exercise + sep + Laterality + sep +
-			ExtraWeight + sep + DisplacedWeight + sep + 
-			Start + sep + Duration + sep + Height + sep + 
-			MeanSpeed + sep + MaxSpeed + sep + MaxSpeedT + sep + 
-			MeanPower + sep + PeakPower + sep + PeakPowerT + sep + 
-			PP_PPT + sep +
-			MeanForce + sep + MaxForce + sep + MaxForceT;
+		
+		string str = "";
+		//TODO: if capture not shown because some variables like Inertia are not defined
+		if(! captureOrAnalyze)
+			str = 
+				N + sep + Series + sep + Exercise + sep + Laterality + sep +
+				ExtraWeight + sep + DisplacedWeight + sep + Inertia + sep + 
+				Start + sep + Duration + sep + Height + sep + 
+				MeanSpeed + sep + MaxSpeed + sep + MaxSpeedT + sep + 
+				MeanPower + sep + PeakPower + sep + PeakPowerT + sep + 
+				PP_PPT + sep +
+				MeanForce + sep + MaxForce + sep + MaxForceT;
 		
 		if(decimalSeparator == "COMMA")
 			str = Util.ConvertToComma(str);
@@ -371,18 +401,22 @@ public class EncoderSignal
 	}
 
 	//this can be an eccentric or concentric curve
-	public int FindPosOfBestMeanPower() {
-		double bestMeanPower = 0;
-		int bestMeanPowerPos = 0;
+	public int FindPosOfBest(string variable) {
+		//TODO: change for the rest of stuff
+		double bestValue = 0;
+		int bestValuePos = 0;
 		int i = 0;
-		foreach(EncoderCurve curve in curves) {
-			if(Convert.ToDouble(curve.MeanPower) > bestMeanPower) {
-				bestMeanPower = Convert.ToDouble(curve.MeanPower);
-				bestMeanPowerPos = i;
+		
+		foreach(EncoderCurve curve in curves) 
+		{
+			if(curve.GetParameter(variable) > bestValue) {
+				bestValue = curve.GetParameter(variable);
+				bestValuePos = i;
 			}
+
 			i++;
 		}
-		return bestMeanPowerPos;
+		return bestValuePos;
 	}
 	
 	~EncoderSignal() {}
@@ -948,6 +982,7 @@ public class EncoderConfiguration {
 	public bool has_angle_push;
 	public bool has_angle_weight;
 	public bool has_inertia;
+	public bool has_gearedDown;
 	public bool rotaryFrictionOnAxis;
 	public double d;	//axis
 	public double D;	//external disc or pulley
@@ -956,6 +991,7 @@ public class EncoderConfiguration {
 	
 	public int inertiaMachine; //this is the inertia without the disc
 	
+	// see methods: GearedUpDisplay() SetGearedDownFromDisplay(string gearedUpStr) 
 	public int gearedDown;	//demultiplication
 	
 	public int inertiaTotal; //this is the inertia used by R
@@ -982,6 +1018,7 @@ public class EncoderConfiguration {
 		has_angle_push = false;
 		has_angle_weight = false;
 		has_inertia = false;
+		has_gearedDown = false; //gearedDown can be changed by user
 		rotaryFrictionOnAxis = false;
 		d = -1;
 		D = -1;
@@ -1006,6 +1043,7 @@ public class EncoderConfiguration {
 		has_angle_push = false;
 		has_angle_weight = false;
 		has_inertia = false;
+		has_gearedDown = false; //gearedDown can be changed by user
 		rotaryFrictionOnAxis = false;
 		gearedDown = 1;
 		list_d = new List<double>(); 
@@ -1110,7 +1148,6 @@ public class EncoderConfiguration {
 			code = "Linear - inertial machine";
 			text = Catalog.GetString("Linear encoder on inertia machine.") + "\n" + 
 				Catalog.GetString("Configuration NOT Recommended! Please use a rotary encoder.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" + 
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 			
 			has_d = true;
@@ -1150,7 +1187,6 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionSideInertial;
 			code = "Rotary friction - inertial machine side";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine side.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
@@ -1163,7 +1199,6 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionSideInertialLateral;
 			code = "Rotary friction - inertial machine side - horizontal movement";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving horizontally.") + "\n" +
-				"*" + Catalog.GetString("Start capture with the rope completely unwrapped.") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
@@ -1176,15 +1211,13 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionSideInertialMovPulley;
 			code = "Rotary friction - inertial machine side geared up";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine geared up.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled") + "\n" + 
 				Catalog.GetString("Inertial machine rolls twice faster than body."); 
 
 			has_d = true;
 			has_D = true;
 			has_inertia = true;
-			
-			gearedDown = -2; //gearedDown is not used in inertial machines. It's hardcoded
+			has_gearedDown = true;
 		}
 
 		// ---- rotary friction on axis
@@ -1194,7 +1227,6 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionAxisInertial;
 			code = "Rotary friction axis - inertial machine axis";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine axis.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" + 
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
@@ -1207,7 +1239,6 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionAxisInertialLateral;
 			code = "Rotary friction - inertial machine axis - horizontal movement";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving horizontally.") + "\n" +
-				"*" + Catalog.GetString("Start capture with the rope completely unwrapped.") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
@@ -1220,15 +1251,13 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionAxisInertialMovPulley;
 			code = "Rotary friction - inertial machine axis geared up";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine geared up.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled") + "\n" + 
 				Catalog.GetString("Inertial machine rolls twice faster than body."); 
 
 			has_d = true;
 			has_inertia = true;
 			rotaryFrictionOnAxis = true;
-			
-			gearedDown = -2; //gearedDown is not used in inertial machines. It's hardcoded
+			has_gearedDown = true;
 		}
 
 		// ---- ROTARY AXIS ----
@@ -1259,7 +1288,6 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderAxisInertial;
 			code = "Rotary axis - inertial machine";
 			text = Catalog.GetString("Rotary axis encoder on inertial machine.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
@@ -1271,7 +1299,6 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderAxisInertialLateral;
 			code = "Rotary axis - inertial machine - horizontal movement";
 			text = Catalog.GetString("Rotary axis encoder on inertial machine when person is moving horizontally.") + "\n" +
-				"*" + Catalog.GetString("Start capture with the rope completely unwrapped.") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
@@ -1283,14 +1310,12 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderAxisInertialMovPulley;
 			code = "Rotary axis - inertial machine geared up";
 			text = Catalog.GetString("Rotary axis encoder on inertial machine geared up.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled") + "\n" + 
 				Catalog.GetString("Inertial machine rolls twice faster than body."); 
 
 			has_d = true;
 			has_inertia = true;
-			
-			gearedDown = -2; //gearedDown is not used in inertial machines. It's hardcoded
+			has_gearedDown = true;
 		}
 	}
 
@@ -1438,4 +1463,342 @@ public class EncoderConfiguration {
 
 		return code + str_d + str_D + str_anglePush + str_angleWeight + str_inertia + str_gearedDown;
 	}
+
+	/*
+	 * IMPORTANT: on GUI is gearedDown is shown as UP (for clarity: 4, 3, 2, 1, 1/2, 1/3, 1/4)
+	 * on C#, R, SQL we use "gearedDown" for historical reasons. So a conversion is done on displaying data to user
+	 * gearedDown is stored as integer on database and is converted to this gearedUp for GUI
+	 * R will do another conversion and will use the double
+	 *   4   ,    3    ,  2  , 1/2, 1/3, 1/4		#gearedUp string (GUI)
+	 *  -4   ,   -3    , -2  ,   2,   3,   4		#gearedDown
+	 *   0.25,    0.333,  0.5,   2,   3,   4		#gearedDown on R (see readFromFile.gearedDown() on util.cs)
+	 */
+	public string GearedUpDisplay() 
+	{
+		switch(gearedDown) {
+			case -4:
+				return "4";
+				break;
+			case -3:
+				return "3";
+				break;
+			case -2:
+				return "2";
+				break;
+			case 2:
+				return "1/2";
+				break;
+			case 3:
+				return "1/3";
+				break;
+			case 4:
+				return "1/4";
+				break;
+			default:
+				return "2";
+				break;
+		}
+	}
+	public void SetGearedDownFromDisplay(string gearedUpStr) 
+	{
+		switch(gearedUpStr) {
+			case "4":
+				gearedDown = -4;
+				break;
+			case "3":
+				gearedDown = -3;
+				break;
+			case "2":
+				gearedDown = -2;
+				break;
+			case "1/2":
+				gearedDown = 2;
+				break;
+			case "1/3":
+				gearedDown = 3;
+				break;
+			case "1/4":
+				gearedDown = 4;
+				break;
+			default:
+				gearedDown = -2;
+				break;
+		}
+	}
+
+}
+
+public class EncoderAnalyzeInstant 
+{
+	public List<double> displ;
+	public List<double> speed;
+	public List<double> accel;
+	public List<double> force;
+	public List<double> power;
+
+	public int graphWidth;
+	
+	private Rx1y2 usr;
+	private Rx1y2 plt;
+		
+	private double pxPlotArea;
+	private double msPlotArea;
+	
+	//last calculated values on last range of msa and msb
+	public double displAverageLast;
+	public double displMaxLast;
+	public double speedAverageLast;
+	public double speedMaxLast;
+	public double accelAverageLast;
+	public double accelMaxLast;
+	public double forceAverageLast;
+	public double forceMaxLast;
+	public double powerAverageLast;
+	public double powerMaxLast;
+
+	public EncoderAnalyzeInstant() {
+		displ = new List<double>(); 
+		speed = new List<double>(); 
+		accel = new List<double>(); 
+		force = new List<double>(); 
+		power = new List<double>();
+		
+		graphWidth = 0;
+		pxPlotArea = 0;
+		msPlotArea = 0;
+	}
+
+	//file has a first line with headers
+	//2nd.... full data
+	public void ReadArrayFile(string filename)
+	{
+		List<string> lines = Util.ReadFileAsStringList(filename);
+		if(lines == null)
+			return;
+		if(lines.Count <= 1) //return if there's only the header
+			return;
+
+		bool headerLine = true;
+		foreach(string l in lines) {
+				if(headerLine) {
+					headerLine = false;
+					continue;
+				}
+
+			string [] lsplit = l.Split(new char[] {','});
+			displ.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(lsplit[1])));
+			speed.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(lsplit[2])));
+			accel.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(lsplit[3])));
+			force.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(lsplit[4])));
+			power.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(lsplit[5])));
+		}
+	}
+	
+	public void ReadGraphParams(string filename)
+	{
+		List<string> lines = Util.ReadFileAsStringList(filename);
+		if(lines == null)
+			return;
+		if(lines.Count < 3)
+			return;
+
+		graphWidth = Convert.ToInt32(lines[0]);
+		usr = new Rx1y2(lines[1]);
+		plt = new Rx1y2(lines[2]);
+
+		// calculate the pixels in plot area
+		pxPlotArea = graphWidth * (plt.x2 - plt.x1);
+
+		//calculate the ms in plot area
+		msPlotArea = usr.x2 - usr.x1;
+	}
+	
+	//gets an instant value
+	public double GetParam(string param, int ms) 
+	{
+		ms --; //converts from starting at 1 (graph) to starting at 0 (data)
+
+		if(ms > displ.Count)
+			return -1;
+
+		else {
+			if(param == "displ")
+				return displ[ms];
+			else if(param == "speed")
+				return speed[ms];
+			else if(param == "accel")
+				return accel[ms];
+			else if(param == "force")
+				return force[ms];
+			else if(param == "power")
+				return power[ms];
+			else
+				return -2;
+		}
+	}
+	
+	//calculates from a range
+	public bool CalculateRangeParams(int msa, int msb)
+	{
+		msa --; //converts from starting at 1 (graph) to starting at 0 (data)
+		msb --; //converts from starting at 1 (graph) to starting at 0 (data)
+		
+		//if msb < msa invert them
+		if(msb < msa) {
+			int temp = msa;
+			msa = msb;
+			msb = temp;
+		}
+
+		if(msa > displ.Count || msb > displ.Count)
+			return false;
+
+		getAverageAndMax(displ, msa, msb, out displAverageLast, out displMaxLast);
+		getAverageAndMax(speed, msa, msb, out speedAverageLast, out speedMaxLast);
+		getAverageAndMax(accel, msa, msb, out accelAverageLast, out accelMaxLast);
+		getAverageAndMax(force, msa, msb, out forceAverageLast, out forceMaxLast);
+		getAverageAndMax(power, msa, msb, out powerAverageLast, out powerMaxLast);
+		
+		return true;
+	}
+	private void getAverageAndMax(List<double> dlist, int ini, int end, out double listAVG, out double listMAX) {
+		if(ini == end) {
+			listAVG = dlist[ini];
+			listMAX = dlist[ini];
+		}
+
+		double sum = 0;
+		double max = - 1000000;
+		for(int i = ini; i <= end; i ++) {
+			sum += dlist[i];
+			if(dlist[i] > max)
+				max = dlist[i];
+		}
+
+		listAVG = sum / (end - ini + 1); //+1 because count starts at 0
+		listMAX = max;
+	}
+
+
+	public int GetVerticalLinePosition(int ms) 
+	{
+		//this can be called on expose event before calculating needed parameters
+		if(graphWidth == 0 || pxPlotArea == 0 || msPlotArea == 0)
+			return 0;
+
+		// rule of three
+		double px = (ms - usr.x1) * pxPlotArea / msPlotArea;
+
+		// fix margin
+		px = px + plt.x1 * graphWidth;
+
+		return Convert.ToInt32(px);
+	}
+	
+	public void ExportToCSV(int msa, int msb, string selectedFileName, string sepString) 
+	{
+		//if msb < msa invert them
+		if(msb < msa) {
+			int temp = msa;
+			msa = msb;
+			msb = temp;
+		}
+
+		//this overwrites if needed
+		TextWriter writer = File.CreateText(selectedFileName);
+
+		string sep = " ";
+		if (sepString == "COMMA")
+			sep = ";";
+		else
+			sep = ",";
+
+		string header = 
+			"" + sep +
+			Catalog.GetString("Time") + sep + 
+			Catalog.GetString("Displacement") + sep +
+			Catalog.GetString("Speed") + sep +
+			Catalog.GetString("Acceleration") + sep +
+			Catalog.GetString("Force") + sep +
+			Catalog.GetString("Power");
+			
+		//write header
+		writer.WriteLine(header);
+
+		//write statistics
+		writer.WriteLine(
+				Catalog.GetString("Difference") + sep +
+				(msb-msa).ToString() + sep +
+				Util.DoubleToCSV( (GetParam("displ",msb) - GetParam("displ",msa)), sepString ) + sep +
+				Util.DoubleToCSV( (GetParam("speed",msb) - GetParam("speed",msa)), sepString ) + sep +
+				Util.DoubleToCSV( (GetParam("accel",msb) - GetParam("accel",msa)), sepString ) + sep +
+				Util.DoubleToCSV( (GetParam("force",msb) - GetParam("force",msa)), sepString ) + sep +
+				Util.DoubleToCSV( (GetParam("power",msb) - GetParam("power",msa)), sepString ) );
+		
+		//done here because GetParam does the same again, and if we put it in the top of this method, it will be done two times
+		msa --; //converts from starting at 1 (graph) to starting at 0 (data)
+		msb --; //converts from starting at 1 (graph) to starting at 0 (data)
+		
+		writer.WriteLine(
+				Catalog.GetString("Average") + sep +
+				"" + sep +
+				Util.DoubleToCSV(displAverageLast, sepString) + sep +
+				Util.DoubleToCSV(speedAverageLast, sepString) + sep +
+				Util.DoubleToCSV(accelAverageLast, sepString) + sep +
+				Util.DoubleToCSV(forceAverageLast, sepString) + sep +
+				Util.DoubleToCSV(powerAverageLast, sepString) );
+		
+		writer.WriteLine(
+				Catalog.GetString("Maximum") + sep +
+				"" + sep +
+				Util.DoubleToCSV(displMaxLast, sepString) + sep +
+				Util.DoubleToCSV(speedMaxLast, sepString) + sep +
+				Util.DoubleToCSV(accelMaxLast, sepString) + sep +
+				Util.DoubleToCSV(forceMaxLast, sepString) + sep +
+				Util.DoubleToCSV(powerMaxLast, sepString) );
+
+		//blank line
+		writer.WriteLine();
+
+		//write header
+		writer.WriteLine(header);
+
+		//write data
+		for(int i = msa; i <= msb; i ++)
+			writer.WriteLine(
+					"" + sep +
+					(i+1).ToString() + sep +
+					Util.DoubleToCSV(displ[i], sepString) + sep +
+					Util.DoubleToCSV(speed[i], sepString) + sep +
+					Util.DoubleToCSV(accel[i], sepString) + sep +
+					Util.DoubleToCSV(force[i], sepString) + sep +
+					Util.DoubleToCSV(power[i], sepString) );
+
+		writer.Flush();
+		writer.Close();
+		((IDisposable)writer).Dispose();
+	}
+
+	public void PrintDebug() {
+		LogB.Information("Printing speed");
+		foreach(double s in speed)
+			LogB.Debug(s.ToString());
+	}
+}
+
+//for objects coming from R that have "x1 x2 y1 y2" like usr or par
+public class Rx1y2 
+{
+	public double x1;
+	public double x2;
+	public double y1;
+	public double y2;
+
+	public Rx1y2 (string s) {
+		string [] sFull = s.Split(new char[] {' '});
+		x1 = Convert.ToDouble(Util.ChangeDecimalSeparator(sFull[0]));
+		x2 = Convert.ToDouble(Util.ChangeDecimalSeparator(sFull[1]));
+		y1 = Convert.ToDouble(Util.ChangeDecimalSeparator(sFull[2]));
+		y2 = Convert.ToDouble(Util.ChangeDecimalSeparator(sFull[3]));
+	}
 }
