@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -937,6 +937,9 @@ public class PersonAddModifyWindow
 			
 		fakeButtonAccept = new Gtk.Button();
 
+		entry1.CanFocus = true;
+		entry1.IsFocus = true;
+
 		if(adding) {
 			person_win.Title = Catalog.GetString ("New jumper");
 			//button_accept.Sensitive = false;
