@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -31,19 +31,23 @@ using Mono.Unix;
 using System.Threading;
 using System.Globalization; //CultureInfo stuff
 
+using System.Diagnostics;  //Stopwatch
+
+
+/*
+using ICSharpCode.SharpZipLib.Tar;
+using ICSharpCode.SharpZipLib.GZip;
+using ICSharpCode.SharpZipLib;
+*/
 
 public class PreferencesWindow {
 	
 	[Widget] Gtk.Window preferences_win;
 
 
-	//database tab
-	[Widget] Gtk.Button button_db_folder_open;
+	//main tab
+	[Widget] Gtk.Button button_data_folder_open;
 
-	//this three are unneded because cannot be unchecked
-	//[Widget] Gtk.CheckButton check_backup_sessions;
-	//[Widget] Gtk.CheckButton check_backup_persons;
-	//[Widget] Gtk.CheckButton check_backup_contact_tests;
 	[Widget] Gtk.CheckButton check_backup_multimedia_and_encoder;
 	
 	[Widget] Gtk.Button button_db_backup;
@@ -93,7 +97,7 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted2;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted3;
-	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_bestmeanpower;
+	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_best;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_all;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_none;
 
@@ -110,16 +114,18 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_graphs_no_translate;
 	[Widget] Gtk.Box hbox_need_restart;
 		
-	//other tab
+	//advanced tab
 	[Widget] Gtk.ComboBox combo_decimals;
 	[Widget] Gtk.CheckButton checkbutton_ask_deletion;
 	[Widget] Gtk.RadioButton radio_export_latin;
 	[Widget] Gtk.RadioButton radio_export_non_latin;
+	[Widget] Gtk.Label label_advanced_feedback;
 
 
 	[Widget] Gtk.Button button_accept;
 	[Widget] Gtk.Button button_cancel;
 	public Gtk.Button FakeButtonImported;
+	public Gtk.Button FakeButtonDebugModeStart;
 	
 	static PreferencesWindow PreferencesWindowBox;
 	
@@ -145,6 +151,7 @@ public class PreferencesWindow {
 		databaseTempURL = Util.GetDatabaseTempDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
 		
 		FakeButtonImported = new Gtk.Button();
+		FakeButtonDebugModeStart = new Gtk.Button();
 	}
 	
 	static public PreferencesWindow Show (Preferences preferences)
@@ -299,8 +306,8 @@ public class PreferencesWindow {
 		else
 			PreferencesWindowBox.radio_do_not_use_heights_on_jump_indexes.Active = true;
 			
-		if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.BESTMEANPOWER)
-			PreferencesWindowBox.radio_encoder_auto_save_curve_bestmeanpower.Active = true;
+		if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.BEST)
+			PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active = true;
 		else if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.ALL)
 			PreferencesWindowBox.radio_encoder_auto_save_curve_all.Active = true;
 		else
@@ -421,13 +428,13 @@ public class PreferencesWindow {
 		}
 	}
 	
-	void on_button_db_folder_open_clicked (object o, EventArgs args)
+	void on_button_data_folder_open_clicked (object o, EventArgs args)
 	{
 		System.IO.FileInfo file1 = new System.IO.FileInfo(databaseURL); //potser cal una arrobar abans (a windows)
 		System.IO.FileInfo file2 = new System.IO.FileInfo(databaseTempURL); //potser cal una arrobar abans (a windows)
 
 		if(file1.Exists)
-			System.Diagnostics.Process.Start(Util.GetDatabaseDir()); 
+			System.Diagnostics.Process.Start(Util.GetParentDir(false)); 
 		else if(file2.Exists)
 			System.Diagnostics.Process.Start(Util.GetDatabaseTempDir()); 
 		else
@@ -479,6 +486,22 @@ public class PreferencesWindow {
 					Constants.DirectoryCannotOpen + "\n\n" + dir);
 		}
 	}
+	
+	void on_button_tmp_folder_open_clicked (object o, EventArgs args)
+	{
+		string dir = UtilAll.GetTempDir(); //potser cal una arrobar abans (a windows)
+		System.IO.FileInfo fInfo = new System.IO.FileInfo(dir);
+
+		try {
+			if(fInfo.Exists)
+				System.Diagnostics.Process.Start(dir);
+		} catch {
+			new DialogMessage(Constants.MessageTypes.WARNING, 
+					Constants.DirectoryCannotOpen + "\n\n" + dir);
+		}
+
+		LogB.Warning(dir);
+	}
 
 
 
@@ -639,11 +662,118 @@ public class PreferencesWindow {
 			new DialogMessage(Constants.MessageTypes.WARNING, myString);
 		}
 	}
-	
+
+	/*
+	 * deprecated since 1.6.0. Use backup method below
+	*/
 	private void copyRecursive() {
 		Util.CopyFilesRecursively(new DirectoryInfo(Util.GetParentDir(false)), new DirectoryInfo(fileCopy));
 	}
+
+	/*
+	 * Temprarily disabled
+	 *
+	//from Longomatch
+	//https://raw.githubusercontent.com/ylatuya/longomatch/master/LongoMatch.DB/CouchbaseStorage.cs
+	private bool backup(string path)
+	{
+		try {   
+			string storageName = path + Path.DirectorySeparatorChar + "chronojump_backup-" + DateTime.UtcNow.ToString() + ".tar.gz";
+			using (FileStream fs = new FileStream (outputFilename, FileMode.Create, FileAccess.Write, FileShare.None)) {
+				using (Stream gzipStream = new GZipOutputStream (fs)) {
+					using (TarArchive tarArchive = TarArchive.CreateOutputTarArchive (gzipStream)) {
+						//foreach (string n in new string[] {"", "-wal", "-shm"}) {
+						//	TarEntry tarEntry = TarEntry.CreateEntryFromFile (
+						//			Path.Combine (Config.DBDir, storageName + ".cblite" + n));
+						//	tarArchive.WriteEntry (tarEntry, true);
+						//}
+						//AddDirectoryFilesToTar (tarArchive, Path.Combine (Config.DBDir, storageName + " attachments"), true);
+						AddDirectoryFilesToTar (tarArchive, Util.GetParentDir(false), true);
+					}
+				}
+			}
+			//LastBackup = DateTime.UtcNow;
+		} catch (Exception ex) {
+			LogB.Error (ex);
+			return false;
+		}
+		return true;
+	}
+
+
+	//from Longomatch
+	//https://raw.githubusercontent.com/ylatuya/longomatch/master/LongoMatch.DB/CouchbaseStorage.cs
+	void AddDirectoryFilesToTar (TarArchive tarArchive, string sourceDirectory, bool recurse)
+	{
+		// Recursively add sub-folders
+		if (recurse) {
+			string[] directories = Directory.GetDirectories (sourceDirectory);
+			foreach (string directory in directories)
+				AddDirectoryFilesToTar (tarArchive, directory, recurse);
+		}
+
+		// Add files
+		string[] filenames = Directory.GetFiles (sourceDirectory);
+		foreach (string filename in filenames) {
+			TarEntry tarEntry = TarEntry.CreateEntryFromFile (filename);
+			tarArchive.WriteEntry (tarEntry, true);
+		}
+	}
+	*/
 	
+	
+	// ---- start SQL stress tests ---->
+
+	private void on_SQL_stress_test_safe_short_clicked (object o, EventArgs args) {
+		LogB.Information("start safe short stress test ---->");
+		sql_stress_test(1000);
+	}
+	private void on_SQL_stress_test_safe_long_clicked (object o, EventArgs args) {
+		LogB.Information("start safe long stress test ---->");
+		sql_stress_test(4000);
+	}
+	private void on_SQL_stress_test_not_safe_short_clicked (object o, EventArgs args) {
+		LogB.Information("start not safe short stress test ---->");
+		Sqlite.SafeClose = false;
+		sql_stress_test(1000);
+		Sqlite.SafeClose = true;
+	}
+	private void on_SQL_stress_test_not_safe_long_clicked (object o, EventArgs args) {
+		LogB.Information("start not safe long stress test ---->");
+		Sqlite.SafeClose = false;
+		sql_stress_test(4000);
+		Sqlite.SafeClose = true;
+	}
+	private void sql_stress_test (int times) {
+		Stopwatch sw = new Stopwatch();
+
+		sw.Start();
+
+		//trying if new way of Sqlite.Close disposing dbcmd fixes problems when multiple open / close connection
+		for(int i=0 ; i < times; i++) {
+			LogB.Debug (" i=" + i.ToString());
+			LogB.Debug(SqlitePreferences.Select("databaseVersion"));
+		}
+		sw.Stop();
+
+		string message = "Success!" + 
+			" Done " + times + " times." + 
+			" Elapsed " + sw.ElapsedMilliseconds + " ms";
+		LogB.Information(message);
+	
+		label_advanced_feedback.Text = message;
+	}
+
+	// <---- end SQL stress tests ----
+
+	private void on_debug_mode_clicked (object o, EventArgs args) {
+		//will be managed from gui/chronojump.cs
+		FakeButtonDebugModeStart.Click();
+	}
+	public void DebugActivated() {
+		label_advanced_feedback.Text = "Debug mode on while Chronojump is running.";
+	}
+
 	private bool PulseGTK ()
 	{
 		if ( ! thread.IsAlive ) {
@@ -673,7 +803,7 @@ public class PreferencesWindow {
 		hbox_backup_doing.Visible = start;
 	
 		button_db_backup.Sensitive = ! start;
-		button_db_folder_open.Sensitive = ! start;
+		button_data_folder_open.Sensitive = ! start;
 		
 		button_cancel.Sensitive = ! start;
 		button_accept.Sensitive = ! start;
@@ -876,9 +1006,9 @@ public class PreferencesWindow {
 			preferences.useHeightsOnJumpIndexes = PreferencesWindowBox.radio_use_heights_on_jump_indexes.Active;
 		}
 
-		if(PreferencesWindowBox.radio_encoder_auto_save_curve_bestmeanpower.Active) {
-			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BESTMEANPOWER.ToString(), true);
-			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.BESTMEANPOWER;
+		if(PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active) {
+			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), true);
+			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.BEST;
 		}
 		else if(PreferencesWindowBox.radio_encoder_auto_save_curve_all.Active) {
 			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.ALL.ToString(), true);
