@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -66,12 +66,12 @@ class SqliteExecuteAuto : Sqlite
 			" (uniqueID, name, mode, description, " +
 			" serie1IDs, serie2IDs, serie3IDs, " + 
 			" future1, future2, future3)" +
-			" VALUES ( NULL, '" +
-			eaSQL.name + "', '" + eaSQL.Mode.ToString() + "', '" + eaSQL.Description + "', '" +
-			eaSQL.SerieIDsToStr(eaSQL.Serie1IDs) + "', '" + 
-			eaSQL.SerieIDsToStr(eaSQL.Serie2IDs) + "', '" + 
-			eaSQL.SerieIDsToStr(eaSQL.Serie3IDs) + "', " + 
-			"'', '', '')"; //future1, future2, future3
+			" VALUES ( NULL, \"" +
+			eaSQL.name + "\", \"" + eaSQL.Mode.ToString() + "\", \"" + eaSQL.Description + "\", \"" +
+			eaSQL.SerieIDsToStr(eaSQL.Serie1IDs) + "\", \"" + 
+			eaSQL.SerieIDsToStr(eaSQL.Serie2IDs) + "\", \"" + 
+			eaSQL.SerieIDsToStr(eaSQL.Serie3IDs) + "\", " + 
+			"\"\", \"\", \"\")"; //future1, future2, future3
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
