@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -202,9 +202,9 @@ class SqliteJumpType : Sqlite
 		}
 		mycmd.CommandText = "INSERT INTO " + Constants.JumpTypeTable +  
 				" (uniqueID, name, startIn, weight, description)" +
-				" VALUES (NULL, '"
-				+ myStr[0] + "', " + myStr[1] + ", " +	//name, startIn
-				myStr[2] + ", '" + myStr[3] + "')" ;	//weight, description
+				" VALUES (NULL, \""
+				+ myStr[0] + "\", " + myStr[1] + ", " +	//name, startIn
+				myStr[2] + ", \"" + myStr[3] + "\")" ;	//weight, description
 		LogB.SQL(mycmd.CommandText.ToString());
 		mycmd.ExecuteNonQuery();
 		if(! dbconOpened) {
@@ -227,10 +227,10 @@ class SqliteJumpType : Sqlite
 		}
 		mycmd.CommandText = "INSERT INTO " + Constants.JumpRjTypeTable + 
 				" (uniqueID, name, startIn, weight, jumpsLimited, fixedValue, description)" +
-				" VALUES (NULL, '"
-				+ myStr[0] + "', " + myStr[1] + ", " +	//name, startIn
+				" VALUES (NULL, \""
+				+ myStr[0] + "\", " + myStr[1] + ", " +	//name, startIn
 				myStr[2] + ", " + myStr[3] + ", " +	//weight, jumpsLimited
-				myStr[4] + ", '" + myStr[5] + "')" ;	//fixedValue, description
+				myStr[4] + ", \"" + myStr[5] + "\")" ;	//fixedValue, description
 		LogB.SQL(mycmd.CommandText.ToString());
 		mycmd.ExecuteNonQuery();
 		if(! dbconOpened) {
@@ -369,8 +369,8 @@ class SqliteJumpType : Sqlite
 			Sqlite.Open();
 		dbcmd.CommandText = "SELECT * " +
 			" FROM " + Constants.JumpTypeTable + " " +
-			" WHERE name  = '" + typeName +
-			"' ORDER BY uniqueID";
+			" WHERE name  = \"" + typeName +
+			"\" ORDER BY uniqueID";
 		
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -401,8 +401,8 @@ class SqliteJumpType : Sqlite
 			Sqlite.Open();
 		dbcmd.CommandText = "SELECT * " +
 			" FROM " + Constants.JumpRjTypeTable + " " +
-			" WHERE name  = '" + typeName +
-			"' ORDER BY uniqueID";
+			" WHERE name  = \"" + typeName +
+			"\" ORDER BY uniqueID";
 		
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -444,7 +444,7 @@ class SqliteJumpType : Sqlite
 		Sqlite.Open();
 		dbcmd.CommandText = "SELECT weight " +
 			" FROM " + tableName +
-			" WHERE name == '" + typeName + "'";
+			" WHERE name == \"" + typeName + "\"";
 		
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -472,7 +472,7 @@ class SqliteJumpType : Sqlite
 		Sqlite.Open();
 		dbcmd.CommandText = "SELECT startIn " +
 			" FROM " + tableName +
-			" WHERE name == '" + typeName + "'";
+			" WHERE name == \"" + typeName + "\"";
 		
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -495,8 +495,8 @@ class SqliteJumpType : Sqlite
 	public static void Update(string nameOld, string nameNew)
 	{
 		//Sqlite.Open();
-		dbcmd.CommandText = "UPDATE jumpType SET name = '" + nameNew + 
-			"' WHERE name == '" + nameOld + "'";
+		dbcmd.CommandText = "UPDATE jumpType SET name = \"" + nameNew + 
+			"\" WHERE name == \"" + nameOld + "\"";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		//Sqlite.Close();
@@ -505,8 +505,8 @@ class SqliteJumpType : Sqlite
 	public static void UpdateOther(string column, string typeName, string newValue)
 	{
 		//Sqlite.Open();
-		dbcmd.CommandText = "UPDATE jumpType SET " + column + " = '" + newValue + 
-			"' WHERE name == '" + typeName + "'";
+		dbcmd.CommandText = "UPDATE jumpType SET " + column + " = \"" + newValue + 
+			"\" WHERE name == \"" + typeName + "\"";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		//Sqlite.Close();
@@ -517,7 +517,7 @@ class SqliteJumpType : Sqlite
 		if(!dbconOpened)
 			Sqlite.Open();
 		dbcmd.CommandText = "Delete FROM " + tableName + 
-			" WHERE name == '" + name + "'";
+			" WHERE name == \"" + name + "\"";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		if(!dbconOpened)
