@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -62,10 +62,10 @@ class SqliteSession : Sqlite
 			uniqueID = "NULL";
 
 		dbcmd.CommandText = "INSERT INTO " + tableName + " (uniqueID, name, place, date, personsSportID, personsSpeciallityID, personsPractice, comments, serverUniqueID)" +
-			" VALUES (" + uniqueID + ", '"
-			+ name + "', '" + place + "', '" + UtilDate.ToSql(date) + "', " + 
+			" VALUES (" + uniqueID + ", \""
+			+ name + "\", \"" + place + "\", \"" + UtilDate.ToSql(date) + "\", " + 
 			personsSportID + ", " + personsSpeciallityID + ", " + 
-			personsPractice + ", '" + comments + "', " +
+			personsPractice + ", \"" + comments + "\", " +
 			serverUniqueID + ")" ;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -87,14 +87,14 @@ class SqliteSession : Sqlite
 		//TODO: serverUniqueID (but cannot be changed in gui/edit, then not need now)
 		Sqlite.Open();
 		dbcmd.CommandText = "UPDATE " + Constants.SessionTable + " " +
-			" SET name = '" + name +
-			"' , date = '" + UtilDate.ToSql(date) +
-			"' , place = '" + place +
-			"' , personsSportID = " + personsSportID +
+			" SET name = \"" + name +
+			"\" , date = \"" + UtilDate.ToSql(date) +
+			"\" , place = \"" + place +
+			"\" , personsSportID = " + personsSportID +
 			", personsSpeciallityID = " + personsSpeciallityID +
 			", personsPractice = " + personsPractice +
-			", comments = '" + comments +
-			"' WHERE uniqueID == " + uniqueID;
+			", comments = \"" + comments +
+			"\" WHERE uniqueID == " + uniqueID;
 		dbcmd.ExecuteNonQuery();
 		Sqlite.Close();
 	}
@@ -119,7 +119,7 @@ class SqliteSession : Sqlite
 	//be careful because name is not unique
 	public static Session SelectByName(string name)
 	{
-		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + " WHERE name == '" + name + "'"; 
+		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + " WHERE name == \"" + name + "\""; 
 		return SelectDo(dbcmd);
 	}
 	//by ID (default
@@ -219,14 +219,20 @@ class SqliteSession : Sqlite
 	}
 
 
-	public static string[] SelectAllSessions() 
+	public static string[] SelectAllSessions(string filterName) 
 	{
 		Sqlite.Open();
+
+		string filterNameString = "";
+		if(filterName != "")
+			filterNameString = " AND LOWER(session.name) LIKE LOWER (\"%" + filterName  + "%\") ";
+
 		dbcmd.CommandText = 
 			"SELECT session.*, sport.name, speciallity.name" +
 			" FROM session, sport, speciallity " +
 			" WHERE session.personsSportID == sport.uniqueID " + 
 			" AND session.personsSpeciallityID == speciallity.UniqueID " +
+			filterNameString + 
 			" ORDER BY session.uniqueID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -386,7 +392,7 @@ class SqliteSession : Sqlite
 	
 		//select encoder signal of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.EncoderTable + 
-			" WHERE signalOrCurve == 'signal' GROUP BY sessionID ORDER BY sessionID";
+			" WHERE signalOrCurve == \"signal\" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -401,7 +407,7 @@ class SqliteSession : Sqlite
 	
 		//select encoder curve of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.EncoderTable + 
-			" WHERE signalOrCurve == 'curve' GROUP BY sessionID ORDER BY sessionID";
+			" WHERE signalOrCurve == \"curve\" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -564,7 +570,7 @@ class SqliteSession : Sqlite
 		dbcmd.CommandText = "SELECT AVG(" + valueToSelect + ")" +
 			" FROM " + table +				
 			" WHERE sessionID == " + sessionID + 
-			" AND type == '" + type + "' " +
+			" AND type == \"" + type + "\" " +
 			personIDString; 
 		
 		LogB.SQL(dbcmd.CommandText.ToString());
@@ -713,13 +719,13 @@ class SqliteServerSession : SqliteSession
 		string uniqueID = "NULL";
 
 		dbcmd.CommandText = "INSERT INTO " + tableName + " (uniqueID, name, place, date, personsSportID, personsSpeciallityID, personsPractice, comments, serverUniqueID, evaluatorID, evaluatorCJVersion, evaluatorOS, uploadedDate, uploadingState)" +
-			" VALUES (" + uniqueID + ", '"
-			+ name + "', '" + place + "', '" + UtilDate.ToSql(date) + "', " + 
+			" VALUES (" + uniqueID + ", \""
+			+ name + "\", \"" + place + "\", \"" + UtilDate.ToSql(date) + "\", " + 
 			personsSportID + ", " + personsSpeciallityID + ", " + 
-			personsPractice + ", '" + comments + "', " +
-			serverUniqueID + ", " + evaluatorID + ", '" +
-			evaluatorCJVersion + "', '" + evaluatorOS + "', '" +
-			UtilDate.ToSql(uploadedDate) + "', " + uploadingState +
+			personsPractice + ", \"" + comments + "\", " +
+			serverUniqueID + ", " + evaluatorID + ", \"" +
+			evaluatorCJVersion + "\", \"" + evaluatorOS + "\", \"" +
+			UtilDate.ToSql(uploadedDate) + "\", " + uploadingState +
 			")" ;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
