@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -52,6 +52,15 @@ public class Util
 		myStringBuilder.Replace(".", ",");
 		return myStringBuilder.ToString();
 	}
+	
+	public static string DoubleToCSV(double d, string CSVsepString) {
+		string s = d.ToString();
+		if(CSVsepString == "COMMA")
+			return ConvertToComma(s);
+		else
+			return ConvertToPoint(s);
+	}
+		
 
 
 	//when we do a query to the server, it returns avg as "0,54" because it's latin localized
@@ -804,7 +813,7 @@ public class Util
 	public static string GetDatabaseTempDir() {
 		return Path.Combine(Path.GetTempPath(), "Chronojump");
 	}
-
+	
 	/********** end of database paths ************/
 
 	/*	
@@ -939,7 +948,7 @@ public class Util
 	/********** start of encoder paths ************/
 
 	public static string GetEncoderExportTempFileName() {
-		return Path.Combine(Path.GetTempPath(), "encoder_export.csv");
+		return Path.Combine(Path.GetTempPath(), "encoder_set_export.csv");
 	}
 
 	/********** end of encoder paths ************/
@@ -1128,6 +1137,8 @@ public class Util
  
 		if (UtilAll.IsWindows())
 			rBin=System.IO.Path.Combine(GetPrefixDir(), "bin/R.exe");
+		else if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.MACOSX)
+			rBin = Constants.ROSX;
 
 		pinfo = new ProcessStartInfo();
 		pinfo.FileName=rBin;
@@ -1214,7 +1225,7 @@ public class Util
 			string pBin="gst-launch-0.10";
 
 			pinfo.FileName=pBin;
-			pinfo.Arguments = "playbin " + @"uri=file://" + fileName;
+			pinfo.Arguments = "playbin2 " + @"uri=file://" + fileName;
 			LogB.Information("Arguments:", pinfo.Arguments);
 			pinfo.CreateNoWindow = true;
 			pinfo.UseShellExecute = false;
@@ -1485,6 +1496,13 @@ public class Util
 		else
 			return 0;
 	}
+	
+	public static string BoolToRBool (bool myBool) {
+		if(myBool)
+			return "TRUE";
+		else
+			return "FALSE";
+	}
 
 	//used by simulated, since cj 0.8.1.2, db: 0.60
 	//-1 simulated test
