@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -158,5 +158,15 @@ public class UtilAll
 	public static string GetLogFileOld() {
 		return Path.Combine(GetLogsDir() +  Path.DirectorySeparatorChar + Constants.FileNameLogOld);
 	}
+	
+	public static string GetTempDir() {
+		string path = Path.GetTempPath();
+
+		path = path.TrimEnd(Path.DirectorySeparatorChar);
+		//on Linux folder cannot be opened either with '/' at the end, or without it
+
+		return path;
+	}
+
 
 }
