@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -117,6 +117,18 @@ public class UtilEncoder
 	public static string GetEncoderSpecialDataTempFileName() {
 		return Path.Combine(Path.GetTempPath(), Constants.EncoderSpecialDataTemp);
 	}
+	public static string GetEncoderInstantDataTempFileName() {
+		return Path.Combine(Path.GetTempPath(), Constants.EncoderInstantDataTemp);
+	}
+	public static string GetEncoderTempPathWithoutLastSep() {
+		string s = Path.GetTempPath(); //is just temp path
+
+		//but send it without the final '\' or '/' (if found)
+		if(s.EndsWith("/") || s.EndsWith("\\"))
+			s = s.Substring(0, s.Length -1);
+
+		return s;
+	}
 
 
 //	public static void MoveTempToEncoderData(int sessionID, int uniqueID) 
@@ -207,6 +219,17 @@ public class UtilEncoder
 				Util.GetDataDir(), "encoder", Constants.EncoderScriptUtilR);
 	}
 	
+	public static string GetEncoderScriptsPathWithoutLastSep() {
+		string s = System.IO.Path.Combine(Util.GetDataDir(), "encoder");
+
+		//but send it without the final '\' or '/' (if found)
+		if(s.EndsWith("/") || s.EndsWith("\\"))
+			s = s.Substring(0, s.Length -1);
+
+		return s;
+	}
+
+	
 	
 	/********** end of encoder paths ************/
 
@@ -272,16 +295,8 @@ public class UtilEncoder
 	}
 	*/
 	
-	public static EncoderGraphROptions PrepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate) 
+	public static EncoderGraphROptions PrepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate, bool debug) 
 	{
-		string scriptUtilR = GetEncoderScriptUtilR();
-
-		string scriptNeuromuscularProfile = "none"; //cannot be blank
-		if(neuromuscularProfileDo)
-			scriptNeuromuscularProfile = GetEncoderScriptNeuromuscularProfile();
-
-		string scriptGraphR = GetEncoderScriptGraph();
-		
 		string operatingSystem = "Linux";
 			
 		title = Util.RemoveBackSlash(title);
@@ -296,11 +311,9 @@ public class UtilEncoder
 			es.InputData = es.InputData.Replace("\\","/");
 			es.OutputGraph = es.OutputGraph.Replace("\\","/");
 			es.OutputData1 = es.OutputData1.Replace("\\","/");
-			es.OutputData2 = es.OutputData2.Replace("\\","/");
-			es.SpecialData = es.SpecialData.Replace("\\","/");
-			scriptUtilR = scriptUtilR.Replace("\\","/");
-			scriptNeuromuscularProfile = scriptNeuromuscularProfile.Replace("\\","/");
-			scriptGraphR = scriptGraphR.Replace("\\","/");
+			//es.OutputData2 = es.OutputData2.Replace("\\","/");
+			//es.SpecialData = es.SpecialData.Replace("\\","/");
+			es.EncoderTempPath = es.EncoderTempPath.Replace("\\","/");
 			operatingSystem = "Windows";
 		}
 		
@@ -332,13 +345,14 @@ public class UtilEncoder
 
 		return new EncoderGraphROptions( 
 				es.InputData, es.OutputGraph, es.OutputData1, 
-				es.OutputData2, es.SpecialData, 
+				//es.OutputData2, es.SpecialData, 
+				es.EncoderRPath, es.EncoderTempPath,
 				es.Ep,
 				title, operatingSystem,
-				scriptUtilR, scriptNeuromuscularProfile,
 				Util.StringArrayToString(Constants.EncoderEnglishWords,";"),
-				Util.StringArrayToString(encoderTranslatedWordsOK,";"), 
-				scriptGraphR);
+				Util.StringArrayToString(encoderTranslatedWordsOK,";"),
+				debug
+				);
 	}
 
 
