@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -549,8 +549,9 @@ public class UtilGtk
 	/*
 	 * OpenImageSafe checks if it's created and if it has size and can be opened
 	 * this is used when one process takes an image from another process and maybe is not finished
+	 * Now we use imageFileWaitUntilCreated()
 	 */
-	public static Gtk.Image OpenImageSafe(string filename, Gtk.Image image) 
+	private static void imageFileWaitUntilCreated(string filename) 
 	{
 		while( ! File.Exists(filename) );
 
@@ -562,7 +563,12 @@ public class UtilGtk
 			else
 				System.Threading.Thread.Sleep(50);
 		} while( ! hasSize );
+	}
 
+	public static Gtk.Image OpenImageSafe(string filename, Gtk.Image image) 
+	{
+		imageFileWaitUntilCreated(filename);
+		
 		bool readedOk;
 		do {
 			readedOk = true;
@@ -579,6 +585,25 @@ public class UtilGtk
 		return image;
 	}
 
+	public static Gdk.Pixbuf OpenPixbufSafe(string filename, Gdk.Pixbuf pixbuf) 
+	{
+		imageFileWaitUntilCreated(filename);
+		
+		bool readedOk;
+		do {
+			readedOk = true;
+			try {
+				pixbuf = new Pixbuf (filename); //from a file
+			} catch {
+				LogB.Warning("File is still not ready. Wait a bit");
+				System.Threading.Thread.Sleep(50);
+				readedOk = false;
+			}
+		} while( ! readedOk );
+
+		return pixbuf;
+	}
+
 
 
 }
